searchData={"items":[{"type":"module","title":"Gate","doc":"Gate is a macro-based library that provides pipeline functionality similar to Phoenix's pipelines.\nIt allows you to define reusable plug pipelines with conditional execution and use them in your Plug.Router.","ref":"Gate.html"},{"type":"module","title":"Usage - Gate","doc":"```elixir\ndefmodule MyApp.Router do\n  use Plug.Router\n  use Gate\n\n  gate :browser do\n    plug :put_resp_content_type, \"text/html\"\n    plug Plug.Logger\n    plug :auth_required\n\n    get \"/\" do\n      send_resp(conn, 200, \"Welcome to the homepage\")\n    end\n  end\n\n  gate :api do\n    plug :put_resp_content_type, \"application/json\"\n    plug Plug.Logger\n\n    get \"/api\" do\n      send_resp(conn, 200, ~s({\"message\": \"Welcome to the API\"}))\n    end\n  end\n\n  match _ do\n    send_resp(conn, 404, \"Oops!\")\n  end\n\n  defp put_resp_content_type(conn, type) do\n    Plug.Conn.put_resp_content_type(conn, type)\n  end\n\n  defp auth_required(conn) do\n    if get_req_header(conn, \"authorization\") == [\"Bearer valid_token\"] do\n      true\n    else\n      Plug.Conn.send_resp(conn, 401, \"Unauthorized\")\n      false\n    end\n  end\nend\n```","ref":"Gate.html#module-usage"},{"type":"macro","title":"Gate.gate/2","doc":"Defines a pipeline of plugs with an optional name.","ref":"Gate.html#gate/2"},{"type":"macro","title":"Example - Gate.gate/2","doc":"gate :browser do\n      plug :put_resp_content_type, \"text/html\"\n      plug Plug.Logger\n    end","ref":"Gate.html#gate/2-example"},{"type":"macro","title":"Gate.get/2","doc":"Defines a GET route within the current pipeline.","ref":"Gate.html#get/2"},{"type":"macro","title":"Example - Gate.get/2","doc":"get \"/\" do\n      send_resp(conn, 200, \"Welcome to the homepage\")\n    end","ref":"Gate.html#get/2-example"},{"type":"macro","title":"Gate.plug/3","doc":"Adds a plug to the current pipeline. Optionally accepts a list of conditions that\nmust be met for the plug to be applied.","ref":"Gate.html#plug/3"},{"type":"macro","title":"Example - Gate.plug/3","doc":"plug :put_resp_content_type, \"text/html\"\n    plug Plug.Logger, []\n    plug MyAuthPlug, [], [auth_required: true]","ref":"Gate.html#plug/3-example"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}